@@ -39,6 +39,11 @@
 # define EAGAIN EWOULDBLOCK
 #endif
 
+void gnutls_free(void *ptr) {
+	if (ptr!=NULL) free(ptr);
+}
+
+
 GNUTLS_Version gnutls_get_current_version(GNUTLS_STATE state) {
 GNUTLS_Version ver;
 	ver.local = state->connection_state.version.local;
@@ -57,6 +62,11 @@ int gnutls_is_secure_memory(const void* mem) {
 	return 0;
 }
 
+int gnutls_set_lowat(GNUTLS_STATE state, int num) {
+	state->gnutls_internals.lowat = num;
+	return 0;
+}
+
 /* This function initializes the state to null (null encryption etc...) */
 int gnutls_init(GNUTLS_STATE * state, ConnectionEnd con_end)
 {
@@ -123,7 +133,16 @@ int gnutls_init(GNUTLS_STATE * state, ConnectionEnd con_end)
 	(*state)->security_parameters.session_id_size = 0;
 	(*state)->gnutls_internals.resumed_security_parameters.session_id_size = 0;
 	(*state)->gnutls_internals.resumed = RESUME_FALSE;
+	
+	(*state)->gnutls_internals.expire_time = 3600; /* one hour default */
 
+	(*state)->security_parameters.timestamp = 0;
+
+	/* gdbm db */
+	(*state)->gnutls_internals.db_name = NULL;
+
+	gnutls_set_lowat((*state), 1); /* the default for tcp */
+	
 	return 0;
 }
 
@@ -164,6 +183,7 @@ int gnutls_deinit(GNUTLS_STATE * state)
 	if ((*state)->gnutls_internals.BulkCipherAlgorithmPriority.algorithm_priority!=NULL)
 		gnutls_free((*state)->gnutls_internals.BulkCipherAlgorithmPriority.algorithm_priority);
 
+	gnutls_free((*state)->gnutls_internals.db_name);
 
 	gnutls_free(*state);
 	return 0;
@@ -517,7 +537,7 @@ ssize_t _gnutls_send_change_cipher_spec(int cd, GNUTLS_STATE state)
 	return ret;
 }
 
-#define RCVLOWAT 1 /* this is the default for TCP - just don't change that! */
+#define RCVLOWAT state->gnutls_internals.lowat /* this is the default for TCP - just don't change that! */
 
 static int _gnutls_clear_peeked_data( int cd, GNUTLS_STATE state) {
 char peekdata;
@@ -637,8 +657,12 @@ ssize_t gnutls_recv_int(int cd, GNUTLS_STATE state, ContentType type, char *data
 /* ok now we are sure that we can read all the data - so
  * move on !
  */
-	_gnutls_Read(cd, headers, HEADER_SIZE, 0); /* read and clear the headers - again! */
-
+	if (_gnutls_Read(cd, headers, HEADER_SIZE, 0)!=HEADER_SIZE) {  /* read and clear the headers - again! */
+		state->gnutls_internals.valid_connection = VALID_FALSE;
+		state->gnutls_internals.resumable = RESUME_FALSE;
+		gnutls_assert();
+		return GNUTLS_E_UNKNOWN_ERROR;
+	}
 /* Read the whole packet - again? */	
 	if ( type==GNUTLS_APPLICATION_DATA) {
 		/* get the data - but do not free the buffer in the kernel */
