@@ -64,6 +64,10 @@ int gnutls_getDataBufferSize(ContentType type, GNUTLS_STATE state)
 	return 0;
 }
 
+int gnutls_check_pending(GNUTLS_STATE state) {
+	return gnutls_getDataBufferSize(GNUTLS_APPLICATION_DATA, state);
+}
+
 int gnutls_getDataFromBuffer(ContentType type, GNUTLS_STATE state, char *data, int length)
 {
 	if (type == GNUTLS_APPLICATION_DATA) {
@@ -108,7 +112,7 @@ int gnutls_getDataFromBuffer(ContentType type, GNUTLS_STATE state, char *data, i
 	return length;
 }
 
-ssize_t _gnutls_Read(int fd, void *iptr, size_t sizeOfPtr)
+ssize_t _gnutls_Read(int fd, void *iptr, size_t sizeOfPtr, int flag)
 {
 	size_t left;
 	ssize_t i=0;
@@ -120,7 +124,7 @@ ssize_t _gnutls_Read(int fd, void *iptr, size_t sizeOfPtr)
 
 	left = sizeOfPtr;
 	while (left > 0) {
-		i = read(fd, &ptr[i], left);
+		i = recv(fd, &ptr[i], left, flag);
 		if (i < 0) {
 			return -1;
 		} else {
@@ -193,7 +197,7 @@ ssize_t _gnutls_Send_int(int fd, GNUTLS_STATE state, ContentType type, void *ipt
 
 	left = n;
 	while (left > 0) {
-		i = gnutls_send_int(fd, state, type, &ptr[i], left);
+		i = gnutls_send_int(fd, state, type, &ptr[i], left, 0);
 		if (i <= 0) {
 			return i;
 		}
@@ -212,7 +216,7 @@ ssize_t _gnutls_Recv_int(int fd, GNUTLS_STATE state, ContentType type, void *ipt
 
 	left = sizeOfPtr;
 	while (left > 0) {
-		i = gnutls_recv_int(fd, state, type, &ptr[i], left);
+		i = gnutls_recv_int(fd, state, type, &ptr[i], left, 0);
 		if (i < 0) {
 			return i;
 		} else {
@@ -234,7 +238,7 @@ int gnutls_insertHashDataBuffer( GNUTLS_STATE state, char *data, int length)
 	old_buffer = state->gnutls_internals.hash_bufferSize;
 
 	state->gnutls_internals.hash_bufferSize += length;
-#ifdef HANDSHAKE_DEBUG
+#ifdef HARD_DEBUG
 	fprintf(stderr, "Inserted %d bytes of Hash Data into buffer\n", length);
 #endif
 	state->gnutls_internals.hash_buffer =
@@ -256,7 +260,7 @@ int gnutls_getHashDataFromBuffer( GNUTLS_STATE state, char *data, int length)
 	if (length > state->gnutls_internals.hash_bufferSize) {
 		length = state->gnutls_internals.hash_bufferSize;
 	}
-#ifdef HANDSHAKE_DEBUG
+#ifdef HARD_DEBUG
 	fprintf(stderr, "Got %d bytes of Hash Data from buffer\n", length);
 #endif
 	state->gnutls_internals.hash_bufferSize -= length;
@@ -278,7 +282,7 @@ int gnutls_readHashDataFromBuffer( GNUTLS_STATE state, char *data, int length)
 	if (length > state->gnutls_internals.hash_bufferSize) {
 		length = state->gnutls_internals.hash_bufferSize;
 	}
-#ifdef HANDSHAKE_DEBUG
+#ifdef HARD_DEBUG
 	fprintf(stderr, "Read %d bytes of Hash Data from buffer\n", length);
 #endif
 	memmove(data, state->gnutls_internals.hash_buffer, length);
@@ -290,7 +294,7 @@ int gnutls_readHashDataFromBuffer( GNUTLS_STATE state, char *data, int length)
 int gnutls_clearHashDataBuffer( GNUTLS_STATE state)
 {
 
-#ifdef HANDSHAKE_DEBUG
+#ifdef HARD_DEBUG
 	fprintf(stderr, "Cleared Hash Data from buffer\n");
 #endif
 	state->gnutls_internals.hash_bufferSize = 0;
