@@ -28,6 +28,8 @@
 #define GNUTLS_E_DECOMPRESSION_FAILED -26
 #define GNUTLS_E_COMPRESSION_FAILED -27
 #define GNUTLS_E_AGAIN -28
+#define GNUTLS_E_EXPIRED -29
+#define GNUTLS_E_DB_ERROR -30
 #define GNUTLS_E_UNIMPLEMENTED_FEATURE -50
 
 
