@@ -35,7 +35,7 @@ GNUTLS_MAC_HANDLE gnutls_hash_init(MACAlgorithm algorithm)
 
 	ret->algorithm = algorithm;
 	switch (algorithm) {
-	case GNUTLS_MAC_NULL:
+	case GNUTLS_NULL_MAC:
 		ret = GNUTLS_HASH_FAILED;
 		break;
 	case GNUTLS_MAC_SHA:
@@ -68,7 +68,7 @@ int gnutls_hash_get_algo_len(MACAlgorithm algorithm)
 	int ret;
 
 	switch (algorithm) {
-	case GNUTLS_MAC_NULL:
+	case GNUTLS_NULL_MAC:
 		ret = 0;
 		break;
 	case GNUTLS_MAC_SHA:
@@ -135,7 +135,7 @@ GNUTLS_MAC_HANDLE gnutls_hmac_init(MACAlgorithm algorithm, void *key,
 	ret->keysize = keylen;
 
 	switch (algorithm) {
-	case GNUTLS_MAC_NULL:
+	case GNUTLS_NULL_MAC:
 		ret = GNUTLS_MAC_FAILED;
 		break;
 	case GNUTLS_MAC_SHA:
@@ -174,7 +174,7 @@ int gnutls_hmac_get_algo_len(MACAlgorithm algorithm)
 	int ret;
 
 	switch (algorithm) {
-	case GNUTLS_MAC_NULL:
+	case GNUTLS_NULL_MAC:
 		ret = 0;
 		break;
 	case GNUTLS_MAC_SHA:
@@ -237,7 +237,6 @@ GNUTLS_MAC_HANDLE gnutls_mac_init_ssl3(MACAlgorithm algorithm, void *key,
 {
 	GNUTLS_MAC_HANDLE ret;
 	char ipad[48];
-	char *digest;
 	int padsize;
 
 	switch (algorithm) {
@@ -269,8 +268,6 @@ GNUTLS_MAC_HANDLE gnutls_mac_init_ssl3_handshake(MACAlgorithm algorithm, void *k
 					int keylen)
 {
 	GNUTLS_MAC_HANDLE ret;
-	char *digest;
-	int padsize;
 
 	ret = gnutls_hash_init(algorithm);
 	if (ret!=GNUTLS_MAC_FAILED) {
@@ -382,7 +379,6 @@ static void *ssl3_sha(int i, char *secret, int secret_len, char *random,
 static void *ssl3_md5(int i, char *secret, int secret_len, char *random,
 	       int random_len)
 {
-	int j;
 	void *digest;
 	GNUTLS_MAC_HANDLE td;
 
